@@ -7,13 +7,13 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 use Dist::Zilla::File::InMemory;
 
 use Moose;
 
-with 'Dist::Zilla::Role::BeforeBuild', 'Dist::Zilla::Role::AfterBuild';
+with 'Dist::Zilla::Role::BeforeBuild';
 
 my $weaver_ini = <<'EOF';
 [@CorePrep]
@@ -50,24 +50,11 @@ my %mailmap = map { $_ => 1 } (
 sub before_build {
     my $self = shift;
 
-    $self->_write_weaver_ini;
     $self->_write_mailmap;
 
     return;
 }
 
-sub _write_weaver_ini {
-    my $self = shift;
-
-    return if -f 'weaver.ini';
-
-    open my $fh, '>', 'weaver.ini';
-    print {$fh} $weaver_ini or die $!;
-    close $fh;
-
-    return;
-}
-
 sub _write_mailmap {
     my $self = shift;
 
@@ -89,14 +76,6 @@ sub _write_mailmap {
     return;
 }
 
-sub after_build {
-    my $self = shift;
-
-    unlink 'weaver.ini';
-
-    return;
-}
-
 __PACKAGE__->meta->make_immutable;
 
 1;
