@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 use Dist::Zilla::PluginBundle::DROLSKY 0.78;
 
@@ -25,6 +25,8 @@ has '+use_github_issues' => (
 
 my %ReplacedPlugins
     = map { 'DROLSKY::' . $_ => 'MAXMIND::' . $_ } qw( Contributors License );
+$ReplacedPlugins{UploadToCPAN}
+    = [ UploadToCPAN => { pause_cfg_file => '.pause-maxmind' } ];
 
 around _build_plugins => sub {
     my $orig = shift;
@@ -118,7 +120,7 @@ Dist::Zilla::PluginBundle::MAXMIND - MaxMind's plugin bundle
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =for Pod::Coverage .*
 
